Tapper Plug v0.2.0 Tapper.Plug.Filter
Tapper filter plug, to prevent tracing of certain URLs.
plug Tapper.Plug.Filter, prefixes: ["__gtg", "/a/path, ["b","path"]]
prefixes- a list of matching path prefixes, given either as path strings, or as a list of path segment strings.
Uses Tapper.Plug.store/2 to set state to :ignore.
Summary
Functions
Callback implementation for Plug.call/2.
Callback implementation for Plug.init/1.